/****************************************************************************
** Meta object code from reading C++ file 'khistorycombobox.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kcompletion-5.39.0/src/khistorycombobox.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'khistorycombobox.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KHistoryComboBox_t {
    QByteArrayData data[12];
    char stringdata0[136];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KHistoryComboBox_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KHistoryComboBox_t qt_meta_stringdata_KHistoryComboBox = {
    {
QT_MOC_LITERAL(0, 0, 16), // "KHistoryComboBox"
QT_MOC_LITERAL(1, 17, 7), // "cleared"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 12), // "addToHistory"
QT_MOC_LITERAL(4, 39, 4), // "item"
QT_MOC_LITERAL(5, 44, 12), // "clearHistory"
QT_MOC_LITERAL(6, 57, 5), // "reset"
QT_MOC_LITERAL(7, 63, 8), // "_k_clear"
QT_MOC_LITERAL(8, 72, 22), // "_k_addContextMenuItems"
QT_MOC_LITERAL(9, 95, 6), // "QMenu*"
QT_MOC_LITERAL(10, 102, 20), // "_k_simulateActivated"
QT_MOC_LITERAL(11, 123, 12) // "historyItems"

    },
    "KHistoryComboBox\0cleared\0\0addToHistory\0"
    "item\0clearHistory\0reset\0_k_clear\0"
    "_k_addContextMenuItems\0QMenu*\0"
    "_k_simulateActivated\0historyItems"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KHistoryComboBox[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       1,   62, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   50,    2, 0x0a /* Public */,
       5,    0,   53,    2, 0x0a /* Public */,
       6,    0,   54,    2, 0x0a /* Public */,
       7,    0,   55,    2, 0x08 /* Private */,
       8,    1,   56,    2, 0x08 /* Private */,
      10,    1,   59,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void, QMetaType::QString,    2,

 // properties: name, type, flags
      11, QMetaType::QStringList, 0x00095103,

       0        // eod
};

void KHistoryComboBox::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KHistoryComboBox *_t = static_cast<KHistoryComboBox *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->cleared(); break;
        case 1: _t->addToHistory((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->clearHistory(); break;
        case 3: _t->reset(); break;
        case 4: _t->d_func()->_k_clear(); break;
        case 5: _t->d_func()->_k_addContextMenuItems((*reinterpret_cast< QMenu*(*)>(_a[1]))); break;
        case 6: _t->d_func()->_k_simulateActivated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KHistoryComboBox::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KHistoryComboBox::cleared)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KHistoryComboBox *_t = static_cast<KHistoryComboBox *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QStringList*>(_v) = _t->historyItems(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KHistoryComboBox *_t = static_cast<KHistoryComboBox *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setHistoryItems(*reinterpret_cast< QStringList*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KHistoryComboBox::staticMetaObject = {
    { &KComboBox::staticMetaObject, qt_meta_stringdata_KHistoryComboBox.data,
      qt_meta_data_KHistoryComboBox,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KHistoryComboBox::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KHistoryComboBox::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KHistoryComboBox.stringdata0))
        return static_cast<void*>(this);
    return KComboBox::qt_metacast(_clname);
}

int KHistoryComboBox::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KComboBox::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KHistoryComboBox::cleared()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
