/****************************************************************************
** Meta object code from reading C++ file 'kcombobox.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kcompletion-5.39.0/src/kcombobox.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcombobox.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KComboBox_t {
    QByteArrayData data[27];
    char stringdata0[374];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KComboBox_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KComboBox_t qt_meta_stringdata_KComboBox = {
    {
QT_MOC_LITERAL(0, 0, 9), // "KComboBox"
QT_MOC_LITERAL(1, 10, 13), // "returnPressed"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 10), // "completion"
QT_MOC_LITERAL(4, 36, 19), // "substringCompletion"
QT_MOC_LITERAL(5, 56, 12), // "textRotation"
QT_MOC_LITERAL(6, 69, 31), // "KCompletionBase::KeyBindingType"
QT_MOC_LITERAL(7, 101, 21), // "completionModeChanged"
QT_MOC_LITERAL(8, 123, 27), // "KCompletion::CompletionMode"
QT_MOC_LITERAL(9, 151, 22), // "aboutToShowContextMenu"
QT_MOC_LITERAL(10, 174, 6), // "QMenu*"
QT_MOC_LITERAL(11, 181, 11), // "contextMenu"
QT_MOC_LITERAL(12, 193, 10), // "rotateText"
QT_MOC_LITERAL(13, 204, 4), // "type"
QT_MOC_LITERAL(14, 209, 16), // "setCompletedText"
QT_MOC_LITERAL(15, 226, 17), // "setCompletedItems"
QT_MOC_LITERAL(16, 244, 5), // "items"
QT_MOC_LITERAL(17, 250, 11), // "autosubject"
QT_MOC_LITERAL(18, 262, 14), // "setCurrentItem"
QT_MOC_LITERAL(19, 277, 4), // "item"
QT_MOC_LITERAL(20, 282, 6), // "insert"
QT_MOC_LITERAL(21, 289, 5), // "index"
QT_MOC_LITERAL(22, 295, 14), // "makeCompletion"
QT_MOC_LITERAL(23, 310, 18), // "_k_lineEditDeleted"
QT_MOC_LITERAL(24, 329, 14), // "autoCompletion"
QT_MOC_LITERAL(25, 344, 15), // "urlDropsEnabled"
QT_MOC_LITERAL(26, 360, 13) // "trapReturnKey"

    },
    "KComboBox\0returnPressed\0\0completion\0"
    "substringCompletion\0textRotation\0"
    "KCompletionBase::KeyBindingType\0"
    "completionModeChanged\0KCompletion::CompletionMode\0"
    "aboutToShowContextMenu\0QMenu*\0contextMenu\0"
    "rotateText\0type\0setCompletedText\0"
    "setCompletedItems\0items\0autosubject\0"
    "setCurrentItem\0item\0insert\0index\0"
    "makeCompletion\0_k_lineEditDeleted\0"
    "autoCompletion\0urlDropsEnabled\0"
    "trapReturnKey"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KComboBox[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       3,  146, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   94,    2, 0x06 /* Public */,
       1,    1,   95,    2, 0x06 /* Public */,
       3,    1,   98,    2, 0x06 /* Public */,
       4,    1,  101,    2, 0x06 /* Public */,
       5,    1,  104,    2, 0x06 /* Public */,
       7,    1,  107,    2, 0x06 /* Public */,
       9,    1,  110,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    1,  113,    2, 0x0a /* Public */,
      14,    1,  116,    2, 0x0a /* Public */,
      15,    2,  119,    2, 0x0a /* Public */,
      15,    1,  124,    2, 0x2a /* Public | MethodCloned */,
      18,    3,  127,    2, 0x0a /* Public */,
      18,    2,  134,    2, 0x2a /* Public | MethodCloned */,
      18,    1,  139,    2, 0x2a /* Public | MethodCloned */,
      22,    1,  142,    2, 0x09 /* Protected */,
      23,    0,  145,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 8,    2,
    QMetaType::Void, 0x80000000 | 10,   11,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 6,   13,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QStringList, QMetaType::Bool,   16,   17,
    QMetaType::Void, QMetaType::QStringList,   16,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool, QMetaType::Int,   19,   20,   21,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,   19,   20,
    QMetaType::Void, QMetaType::QString,   19,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,

 // properties: name, type, flags
      24, QMetaType::Bool, 0x00095103,
      25, QMetaType::Bool, 0x00095103,
      26, QMetaType::Bool, 0x00095103,

       0        // eod
};

void KComboBox::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KComboBox *_t = static_cast<KComboBox *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->returnPressed(); break;
        case 1: _t->returnPressed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->completion((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->substringCompletion((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->textRotation((*reinterpret_cast< KCompletionBase::KeyBindingType(*)>(_a[1]))); break;
        case 5: _t->completionModeChanged((*reinterpret_cast< KCompletion::CompletionMode(*)>(_a[1]))); break;
        case 6: _t->aboutToShowContextMenu((*reinterpret_cast< QMenu*(*)>(_a[1]))); break;
        case 7: _t->rotateText((*reinterpret_cast< KCompletionBase::KeyBindingType(*)>(_a[1]))); break;
        case 8: _t->setCompletedText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->setCompletedItems((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 10: _t->setCompletedItems((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 11: _t->setCurrentItem((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 12: _t->setCurrentItem((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 13: _t->setCurrentItem((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 14: _t->makeCompletion((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 15: _t->d_func()->_k_lineEditDeleted(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KComboBox::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KComboBox::returnPressed)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KComboBox::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KComboBox::returnPressed)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KComboBox::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KComboBox::completion)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KComboBox::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KComboBox::substringCompletion)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KComboBox::*_t)(KCompletionBase::KeyBindingType );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KComboBox::textRotation)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (KComboBox::*_t)(KCompletion::CompletionMode );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KComboBox::completionModeChanged)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (KComboBox::*_t)(QMenu * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KComboBox::aboutToShowContextMenu)) {
                *result = 6;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KComboBox *_t = static_cast<KComboBox *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->autoCompletion(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->urlDropsEnabled(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->trapReturnKey(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KComboBox *_t = static_cast<KComboBox *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAutoCompletion(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setUrlDropsEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 2: _t->setTrapReturnKey(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KComboBox::staticMetaObject = {
    { &QComboBox::staticMetaObject, qt_meta_stringdata_KComboBox.data,
      qt_meta_data_KComboBox,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KComboBox::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KComboBox::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KComboBox.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KCompletionBase"))
        return static_cast< KCompletionBase*>(this);
    return QComboBox::qt_metacast(_clname);
}

int KComboBox::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QComboBox::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 16;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 3;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KComboBox::returnPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KComboBox::returnPressed(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KComboBox::completion(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KComboBox::substringCompletion(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KComboBox::textRotation(KCompletionBase::KeyBindingType _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KComboBox::completionModeChanged(KCompletion::CompletionMode _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KComboBox::aboutToShowContextMenu(QMenu * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
