/****************************************************************************
** Meta object code from reading C++ file 'klineedit.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kcompletion-5.39.0/src/klineedit.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'klineedit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KLineEdit_t {
    QByteArrayData data[43];
    char stringdata0[684];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KLineEdit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KLineEdit_t qt_meta_stringdata_KLineEdit = {
    {
QT_MOC_LITERAL(0, 0, 9), // "KLineEdit"
QT_MOC_LITERAL(1, 10, 22), // "completionBoxActivated"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 13), // "returnPressed"
QT_MOC_LITERAL(4, 48, 10), // "completion"
QT_MOC_LITERAL(5, 59, 19), // "substringCompletion"
QT_MOC_LITERAL(6, 79, 15), // "userTextChanged"
QT_MOC_LITERAL(7, 95, 12), // "textRotation"
QT_MOC_LITERAL(8, 108, 31), // "KCompletionBase::KeyBindingType"
QT_MOC_LITERAL(9, 140, 21), // "completionModeChanged"
QT_MOC_LITERAL(10, 162, 27), // "KCompletion::CompletionMode"
QT_MOC_LITERAL(11, 190, 22), // "aboutToShowContextMenu"
QT_MOC_LITERAL(12, 213, 6), // "QMenu*"
QT_MOC_LITERAL(13, 220, 11), // "contextMenu"
QT_MOC_LITERAL(14, 232, 18), // "clearButtonClicked"
QT_MOC_LITERAL(15, 251, 11), // "setReadOnly"
QT_MOC_LITERAL(16, 263, 10), // "rotateText"
QT_MOC_LITERAL(17, 274, 4), // "type"
QT_MOC_LITERAL(18, 279, 16), // "setCompletedText"
QT_MOC_LITERAL(19, 296, 17), // "setCompletedItems"
QT_MOC_LITERAL(20, 314, 5), // "items"
QT_MOC_LITERAL(21, 320, 11), // "autoSuggest"
QT_MOC_LITERAL(22, 332, 15), // "setSqueezedText"
QT_MOC_LITERAL(23, 348, 4), // "text"
QT_MOC_LITERAL(24, 353, 7), // "setText"
QT_MOC_LITERAL(25, 361, 15), // "setPasswordMode"
QT_MOC_LITERAL(26, 377, 12), // "passwordMode"
QT_MOC_LITERAL(27, 390, 14), // "makeCompletion"
QT_MOC_LITERAL(28, 405, 13), // "userCancelled"
QT_MOC_LITERAL(29, 419, 10), // "cancelText"
QT_MOC_LITERAL(30, 430, 14), // "_k_textChanged"
QT_MOC_LITERAL(31, 445, 26), // "_k_completionMenuActivated"
QT_MOC_LITERAL(32, 472, 8), // "QAction*"
QT_MOC_LITERAL(33, 481, 21), // "_k_tripleClickTimeout"
QT_MOC_LITERAL(34, 503, 25), // "_k_restoreSelectionColors"
QT_MOC_LITERAL(35, 529, 27), // "_k_completionBoxTextChanged"
QT_MOC_LITERAL(36, 557, 24), // "_k_updateClearButtonIcon"
QT_MOC_LITERAL(37, 582, 18), // "contextMenuEnabled"
QT_MOC_LITERAL(38, 601, 15), // "urlDropsEnabled"
QT_MOC_LITERAL(39, 617, 17), // "trapEnterKeyEvent"
QT_MOC_LITERAL(40, 635, 19), // "squeezedTextEnabled"
QT_MOC_LITERAL(41, 655, 12), // "clickMessage"
QT_MOC_LITERAL(42, 668, 15) // "showClearButton"

    },
    "KLineEdit\0completionBoxActivated\0\0"
    "returnPressed\0completion\0substringCompletion\0"
    "userTextChanged\0textRotation\0"
    "KCompletionBase::KeyBindingType\0"
    "completionModeChanged\0KCompletion::CompletionMode\0"
    "aboutToShowContextMenu\0QMenu*\0contextMenu\0"
    "clearButtonClicked\0setReadOnly\0"
    "rotateText\0type\0setCompletedText\0"
    "setCompletedItems\0items\0autoSuggest\0"
    "setSqueezedText\0text\0setText\0"
    "setPasswordMode\0passwordMode\0"
    "makeCompletion\0userCancelled\0cancelText\0"
    "_k_textChanged\0_k_completionMenuActivated\0"
    "QAction*\0_k_tripleClickTimeout\0"
    "_k_restoreSelectionColors\0"
    "_k_completionBoxTextChanged\0"
    "_k_updateClearButtonIcon\0contextMenuEnabled\0"
    "urlDropsEnabled\0trapEnterKeyEvent\0"
    "squeezedTextEnabled\0clickMessage\0"
    "showClearButton"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KLineEdit[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      27,   14, // methods
       7,  222, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  149,    2, 0x06 /* Public */,
       3,    1,  152,    2, 0x06 /* Public */,
       4,    1,  155,    2, 0x06 /* Public */,
       5,    1,  158,    2, 0x06 /* Public */,
       6,    1,  161,    2, 0x16 /* Public | MethodCompatibility */,
       7,    1,  164,    2, 0x06 /* Public */,
       9,    1,  167,    2, 0x06 /* Public */,
      11,    1,  170,    2, 0x06 /* Public */,
      14,    0,  173,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      15,    1,  174,    2, 0x0a /* Public */,
      16,    1,  177,    2, 0x0a /* Public */,
      18,    1,  180,    2, 0x0a /* Public */,
      19,    2,  183,    2, 0x0a /* Public */,
      19,    1,  188,    2, 0x2a /* Public | MethodCloned */,
      22,    1,  191,    2, 0x0a /* Public */,
      24,    1,  194,    2, 0x0a /* Public */,
      25,    1,  197,    2, 0x0a /* Public */,
      25,    0,  200,    2, 0x2a /* Public | MethodCloned */,
      26,    0,  201,    2, 0x0a /* Public */,
      27,    1,  202,    2, 0x09 /* Protected */,
      28,    1,  205,    2, 0x09 /* Protected */,
      30,    1,  208,    2, 0x08 /* Private */,
      31,    1,  211,    2, 0x08 /* Private */,
      33,    0,  214,    2, 0x08 /* Private */,
      34,    0,  215,    2, 0x08 /* Private */,
      35,    1,  216,    2, 0x08 /* Private */,
      36,    1,  219,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, 0x80000000 | 8,    2,
    QMetaType::Void, 0x80000000 | 10,    2,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, 0x80000000 | 8,   17,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QStringList, QMetaType::Bool,   20,   21,
    QMetaType::Void, QMetaType::QStringList,   20,
    QMetaType::Void, QMetaType::QString,   23,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Bool,   26,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,   29,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, 0x80000000 | 32,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,

 // properties: name, type, flags
      37, QMetaType::Bool, 0x00095103,
      38, QMetaType::Bool, 0x00095103,
      39, QMetaType::Bool, 0x00095003,
      40, QMetaType::Bool, 0x00095103,
      41, QMetaType::QString, 0x00095103,
      42, QMetaType::Bool, 0x00095003,
      26, QMetaType::Bool, 0x00095103,

       0        // eod
};

void KLineEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KLineEdit *_t = static_cast<KLineEdit *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->completionBoxActivated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->returnPressed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->completion((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->substringCompletion((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->userTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->textRotation((*reinterpret_cast< KCompletionBase::KeyBindingType(*)>(_a[1]))); break;
        case 6: _t->completionModeChanged((*reinterpret_cast< KCompletion::CompletionMode(*)>(_a[1]))); break;
        case 7: _t->aboutToShowContextMenu((*reinterpret_cast< QMenu*(*)>(_a[1]))); break;
        case 8: _t->clearButtonClicked(); break;
        case 9: _t->setReadOnly((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->rotateText((*reinterpret_cast< KCompletionBase::KeyBindingType(*)>(_a[1]))); break;
        case 11: _t->setCompletedText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 12: _t->setCompletedItems((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 13: _t->setCompletedItems((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 14: _t->setSqueezedText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 15: _t->setText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 16: _t->setPasswordMode((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->setPasswordMode(); break;
        case 18: { bool _r = _t->passwordMode();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->makeCompletion((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 20: _t->userCancelled((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 21: _t->d_func()->_k_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 22: _t->d_func()->_k_completionMenuActivated((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 23: _t->d_func()->_k_tripleClickTimeout(); break;
        case 24: _t->d_func()->_k_restoreSelectionColors(); break;
        case 25: _t->d_func()->_k_completionBoxTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 26: _t->d_func()->_k_updateClearButtonIcon((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KLineEdit::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KLineEdit::completionBoxActivated)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KLineEdit::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KLineEdit::returnPressed)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KLineEdit::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KLineEdit::completion)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KLineEdit::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KLineEdit::substringCompletion)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KLineEdit::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KLineEdit::userTextChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (KLineEdit::*_t)(KCompletionBase::KeyBindingType );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KLineEdit::textRotation)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (KLineEdit::*_t)(KCompletion::CompletionMode );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KLineEdit::completionModeChanged)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (KLineEdit::*_t)(QMenu * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KLineEdit::aboutToShowContextMenu)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (KLineEdit::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KLineEdit::clearButtonClicked)) {
                *result = 8;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KLineEdit *_t = static_cast<KLineEdit *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isContextMenuEnabled(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->urlDropsEnabled(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->trapReturnKey(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->isSqueezedTextEnabled(); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->clickMessage(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->isClearButtonShown(); break;
        case 6: *reinterpret_cast< bool*>(_v) = _t->passwordMode(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KLineEdit *_t = static_cast<KLineEdit *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setContextMenuEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setUrlDropsEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 2: _t->setTrapReturnKey(*reinterpret_cast< bool*>(_v)); break;
        case 3: _t->setSqueezedTextEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 4: _t->setClickMessage(*reinterpret_cast< QString*>(_v)); break;
        case 5: _t->setClearButtonShown(*reinterpret_cast< bool*>(_v)); break;
        case 6: _t->setPasswordMode(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KLineEdit::staticMetaObject = {
    { &QLineEdit::staticMetaObject, qt_meta_stringdata_KLineEdit.data,
      qt_meta_data_KLineEdit,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KLineEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KLineEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KLineEdit.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KCompletionBase"))
        return static_cast< KCompletionBase*>(this);
    return QLineEdit::qt_metacast(_clname);
}

int KLineEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QLineEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 27;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 7;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KLineEdit::completionBoxActivated(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KLineEdit::returnPressed(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KLineEdit::completion(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KLineEdit::substringCompletion(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KLineEdit::userTextChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KLineEdit::textRotation(KCompletionBase::KeyBindingType _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KLineEdit::completionModeChanged(KCompletion::CompletionMode _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KLineEdit::aboutToShowContextMenu(QMenu * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void KLineEdit::clearButtonClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
